"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _colord = require("colord");

var _names = _interopRequireDefault(require("colord/plugins/names"));

var _toShorthand = _interopRequireDefault(require("./lib/toShorthand"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _colord.extend)([_names.default]);

var _default = (colour, isLegacy = false) => {
  if ((0, _colord.getFormat)(colour) === 'rgb') {
    /* check that it is a valid CSS value
     https://www.w3.org/TR/css-color-4/#rgb-functions */
    let percentCount = 0;

    for (const c of colour) {
      if (c === '%') {
        percentCount++;
      }
    } // rgb values should either be all percentages or all numbers


    if (percentCount !== 3 && percentCount !== 0) {
      return colour;
    }
  }

  const parsed = (0, _colord.colord)(colour.toLowerCase());

  if (parsed.isValid()) {
    const alpha = parsed.alpha();

    if (alpha === 1) {
      const toHex = (0, _toShorthand.default)(parsed.toHex());
      const toName = parsed.toName();

      if (toName && toName.length < toHex.length) {
        return toName;
      } else {
        return toHex;
      }
    } else {
      const rgb = parsed.toRgb();

      if (!isLegacy && !rgb.r && !rgb.g && !rgb.b && !alpha) {
        return 'transparent';
      }

      let hsla = parsed.toHslString();
      let rgba = parsed.toRgbString();
      const shortestConversion = hsla.length < rgba.length ? hsla : rgba;
      let result;

      if (colour.length < shortestConversion.length) {
        result = colour;
      } else {
        result = shortestConversion;
      }

      return result;
    }
  } else {
    // Possibly malformed, so pass through
    return colour;
  }
};

exports.default = _default;
module.exports = exports.default;